==> linstor-server-1.13.1.tar.gz: linstor-server-1.13.1/satellite/src/main/java/com/linbit/linstor/dbdrivers/SatelliteResDfnDriver.java <==
package com.linbit.linstor.dbdrivers;

import com.linbit.linstor.core.CoreModule;
import com.linbit.linstor.core.objects.ResourceDefinition;
import com.linbit.linstor.core.objects.ResourceGroup;
import com.linbit.linstor.dbdrivers.interfaces.ResourceDefinitionDatabaseDriver;
import com.linbit.linstor.dbdrivers.interfaces.updater.CollectionDatabaseDriver;
import com.linbit.linstor.dbdrivers.interfaces.updater.SingleColumnDatabaseDriver;
import com.linbit.linstor.dbdrivers.noop.NoOpCollectionDatabaseDriver;
import com.linbit.linstor.stateflags.StateFlagsPersistence;
import com.linbit.linstor.storage.kinds.DeviceLayerKind;

import javax.inject.Inject;

public class SatelliteResDfnDriver implements ResourceDefinitionDatabaseDriver
{
    private final StateFlagsPersistence<?> stateFlagsDriver = new SatelliteFlagDriver();
    private final CollectionDatabaseDriver<?, ?> noOpColDriver = new NoOpCollectionDatabaseDriver<>();
    private final SingleColumnDatabaseDriver<?, ?> noopSingleColDriver = new SatelliteSingleColDriver<>();
    private final CoreModule.ResourceDefinitionMap resDfnMap;

    @Inject
    public SatelliteResDfnDriver(CoreModule.ResourceDefinitionMap resDfnMapRef)
    {
        resDfnMap = resDfnMapRef;
    }

    @SuppressWarnings("unchecked")
    @Override
    public StateFlagsPersistence<ResourceDefinition> getStateFlagsPersistence()
    {
        return (StateFlagsPersistence<ResourceDefinition>) stateFlagsDriver;
    }

    @Override
    public void create(ResourceDefinition resDfn)
    {
        // no-op
    }

    @Override
    public void delete(ResourceDefinition data)
    {
        // no-op
    }

    @SuppressWarnings("unchecked")
    @Override
    public CollectionDatabaseDriver<ResourceDefinition, DeviceLayerKind> getLayerStackDriver()
    {
        return (CollectionDatabaseDriver<ResourceDefinition, DeviceLayerKind>) noOpColDriver;
    }

    @SuppressWarnings("unchecked")
    @Override
    public SingleColumnDatabaseDriver<ResourceDefinition, ResourceGroup> getRscGrpDriver()
    {
        return (SingleColumnDatabaseDriver<ResourceDefinition, ResourceGroup>) noopSingleColDriver;
    }
}

==> linstor-server-1.15.0.tar.gz: linstor-server-1.15.0/satellite/src/main/java/com/linbit/linstor/dbdrivers/SatelliteResDfnDriver.java <==
package com.linbit.linstor.dbdrivers;

import com.linbit.linstor.core.CoreModule;
import com.linbit.linstor.core.objects.ResourceDefinition;
import com.linbit.linstor.core.objects.ResourceGroup;
import com.linbit.linstor.dbdrivers.interfaces.ResourceDefinitionDatabaseDriver;
import com.linbit.linstor.dbdrivers.interfaces.updater.CollectionDatabaseDriver;
import com.linbit.linstor.dbdrivers.interfaces.updater.SingleColumnDatabaseDriver;
import com.linbit.linstor.dbdrivers.noop.NoOpCollectionDatabaseDriver;
import com.linbit.linstor.dbdrivers.noop.NoOpFlagDriver;
import com.linbit.linstor.stateflags.StateFlagsPersistence;
import com.linbit.linstor.storage.kinds.DeviceLayerKind;

import javax.inject.Inject;

public class SatelliteResDfnDriver implements ResourceDefinitionDatabaseDriver
{
    private final StateFlagsPersistence<?> stateFlagsDriver = new NoOpFlagDriver();
    private final CollectionDatabaseDriver<?, ?> noOpColDriver = new NoOpCollectionDatabaseDriver<>();
    private final SingleColumnDatabaseDriver<?, ?> noopSingleColDriver = new SatelliteSingleColDriver<>();
    private final CoreModule.ResourceDefinitionMap resDfnMap;

    @Inject
    public SatelliteResDfnDriver(CoreModule.ResourceDefinitionMap resDfnMapRef)
    {
        resDfnMap = resDfnMapRef;
    }

    @SuppressWarnings("unchecked")
    @Override
    public StateFlagsPersistence<ResourceDefinition> getStateFlagsPersistence()
    {
        return (StateFlagsPersistence<ResourceDefinition>) stateFlagsDriver;
    }

    @Override
    public void create(ResourceDefinition resDfn)
    {
        // no-op
    }

    @Override
    public void delete(ResourceDefinition data)
    {
        // no-op
    }

    @SuppressWarnings("unchecked")
    @Override
    public CollectionDatabaseDriver<ResourceDefinition, DeviceLayerKind> getLayerStackDriver()
    {
        return (CollectionDatabaseDriver<ResourceDefinition, DeviceLayerKind>) noOpColDriver;
    }

    @SuppressWarnings("unchecked")
    @Override
    public SingleColumnDatabaseDriver<ResourceDefinition, ResourceGroup> getRscGrpDriver()
    {
        return (SingleColumnDatabaseDriver<ResourceDefinition, ResourceGroup>) noopSingleColDriver;
    }
}
